var a00059 =
[
    [ "salhelper::ORealDynamicLoader", "a00570.html", "a00570" ],
    [ "salhelper::ODynamicLoader&lt; API &gt;", "a00574.html", "a00574" ],
    [ "salhelper::m_pStaticLoader", "a00531.html#ad64e046d241054478484e163a7ba0f80", null ]
];